PaymentRequiredError class

Error thrown when payment is required (402).

Inheritance

Constructors

PaymentRequiredError({String message = 'Payment required to access this feature'})
const

Properties

code String
Error code for programmatic handling.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
HTTP status code if applicable.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited