StatusColors class

Colors for each feedback status.

Constructors

StatusColors({Color pending = const Color(0xFF6B7280), Color approved = const Color(0xFF3B82F6), Color inProgress = const Color(0xFFF97316), Color testflight = const Color(0xFF06B6D4), Color completed = const Color(0xFF22C55E), Color rejected = const Color(0xFFEF4444)})
const

Properties

approved Color
final
completed Color
final
hashCode int
The hash code for this object.
no setteroverride
inProgress Color
final
pending Color
final
rejected Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testflight Color
final

Methods

copyWith({Color? pending, Color? approved, Color? inProgress, Color? testflight, Color? completed, Color? rejected}) StatusColors
Creates a copy with the given colors replaced.
forStatus(FeedbackStatus status) Color
Gets the color for a status.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override